# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables
from . import outputs
from ._inputs import *

__all__ = ['Vlan']


class Vlan(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr_block: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 linodes: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Create a Vlan resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cidr_block: The CIDR block for this VLAN.
        :param pulumi.Input[str] description: Description of the vlan for display purposes only.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] linodes: A list of IDs of Linodes to attach to this VLAN.
        :param pulumi.Input[str] region: The region of where the VLAN is deployed.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['cidr_block'] = cidr_block
            __props__['description'] = description
            __props__['linodes'] = linodes
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__['region'] = region
            __props__['attached_linodes'] = None
        super(Vlan, __self__).__init__(
            'linode:index/vlan:Vlan',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            attached_linodes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VlanAttachedLinodeArgs']]]]] = None,
            cidr_block: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            linodes: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
            region: Optional[pulumi.Input[str]] = None) -> 'Vlan':
        """
        Get an existing Vlan resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VlanAttachedLinodeArgs']]]] attached_linodes: The Linodes attached to this vlan.
        :param pulumi.Input[str] cidr_block: The CIDR block for this VLAN.
        :param pulumi.Input[str] description: Description of the vlan for display purposes only.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] linodes: A list of IDs of Linodes to attach to this VLAN.
        :param pulumi.Input[str] region: The region of where the VLAN is deployed.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["attached_linodes"] = attached_linodes
        __props__["cidr_block"] = cidr_block
        __props__["description"] = description
        __props__["linodes"] = linodes
        __props__["region"] = region
        return Vlan(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="attachedLinodes")
    def attached_linodes(self) -> pulumi.Output[Sequence['outputs.VlanAttachedLinode']]:
        """
        The Linodes attached to this vlan.
        """
        return pulumi.get(self, "attached_linodes")

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> pulumi.Output[Optional[str]]:
        """
        The CIDR block for this VLAN.
        """
        return pulumi.get(self, "cidr_block")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Description of the vlan for display purposes only.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def linodes(self) -> pulumi.Output[Optional[Sequence[int]]]:
        """
        A list of IDs of Linodes to attach to this VLAN.
        """
        return pulumi.get(self, "linodes")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[str]:
        """
        The region of where the VLAN is deployed.
        """
        return pulumi.get(self, "region")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

